﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ComponentModel;
using System.Diagnostics;
using System.Runtime.CompilerServices;
using System.Windows;

namespace SurfaceChartHighlight
{
    public class DataSource : List<DataPoint>
    {
        public DataSource()
        {
            this.Add(new DataPoint { KPA = 8000, RPM = -100, Threshold = 62 });
            this.Add(new DataPoint { KPA = 8000, RPM = 0, Threshold = 49 });
            this.Add(new DataPoint { KPA = 8000, RPM = 100, Threshold = 45 });

            this.Add(new DataPoint { KPA = 6000, RPM = -100, Threshold = 62 });
            this.Add(new DataPoint { KPA = 6000, RPM = 0, Threshold = 49 });
            this.Add(new DataPoint { KPA = 6000, RPM = 100, Threshold = 45 });

            this.Add(new DataPoint { KPA = 4000, RPM = -100, Threshold = 63 });
            this.Add(new DataPoint { KPA = 4000, RPM = 0, Threshold = 48, IsSelected= true, });
            this.Add(new DataPoint { KPA = 4000, RPM = 100, Threshold = 44 });

            this.Add(new DataPoint { KPA = 2000, RPM = -100, Threshold = 73 });
            this.Add(new DataPoint { KPA = 2000, RPM = 0, Threshold = 60 });
            this.Add(new DataPoint { KPA = 2000, RPM = 100, Threshold = 57 });



        }
    }
    public class DataPoint : ObservableModel
    { 
        private double _KPA;
        /// <summary> Gets or sets KPA coordinate </summary>
        public double KPA
        {
            get { return _KPA; }
            set { if (_KPA == value) return; _KPA = value; OnPropertyChanged("KPA"); }
        }

        private double _RPM;
        /// <summary> Gets or sets RPM coordinate </summary>
        public double RPM
        {
            get { return _RPM; }
            set { if (_RPM == value) return; _RPM = value; OnPropertyChanged("RPM"); }
        }
        
        private double _Threshold;
        /// <summary> Gets or sets Threshold coordinate </summary>
        public double Threshold
        {
            get { return _Threshold; }
            set { if (_Threshold == value) return; _Threshold = value; OnPropertyChanged("Threshold"); }
        }

        private bool _IsSelected = false;
        /// <summary> Gets or sets IsSelected </summary>
        public bool IsSelected
        {
            get { return _IsSelected; }
            set
            {
                if (_IsSelected == value) return; _IsSelected = value;
                OnPropertyChanged("IsSelected"); 
            }
        } 

    }

    public abstract class ObservableModel : INotifyPropertyChanged
    {
        protected ObservableModel()
        { 
        }
        public event PropertyChangedEventHandler PropertyChanged;
        
        protected void OnPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            var handler = this.PropertyChanged;
            if (handler != null)
            { 
                handler(sender, e);
            }
        }

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = "")
        {
            if (PropertyChanged != null)
            {
                OnPropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
         

    }
    
}
